from setuptools import setup, find_packages
setup(
	name                = 'jhpbar',
	version             = '1.2',
	description         = 'custom progress bar bug fix',
    author              = 'jh.kim',
	author_email        = 'biz.jh.kim@gmail.com',
    url                 = 'https://github.com/jhkim31/jh-pbar',
	download_url        = '',
	install_requires    =  [],
    packages            = find_packages(exclude = []),
	keywords            = ['progress_bar'],
	python_requires     = '>=3',
	package_data        = {},
	zip_safe            = False,
	classifiers         = [
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
)
